<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN activado</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN desactivado</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Bloqueo de mayúsculas activado</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Bloqueo de mayúsculas desactivado</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Teclado numérico activado</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Teclado numérico desactivado</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad activado</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad desactivado</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Alternar Touchpad</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Alternar Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Modo avión activado</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Modo avión desactivado</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Potencia equilibrada</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Guarda potencia</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Alta potencia</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Efectos de ventana activados</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Efectos de ventana desactivados</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>No se pudo activar los efectos de ventana</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>